@@ -17,6 +17,25 @@ aliases = {
     },
 }
 
+
+# Features in container.yaml can be boolean or null, as they need to be
+# container technology agnostic
+features = {
+    "type": "object",
+    "patternProperties": {"\\w[\\w-]*": {"type": ["boolean", "null"]}},
+}
+
+# container features can be null or a known string
+container_features = {
+    "type": "object",
+    "properties": {
+        "gpu": {
+            "oneOf": [{"type": "null"}, {"type": "string", "enum": ["nvidia", "amd"]}]
+        }
+    },
+}
+
+
 # Or a list
 aliases_list = {
     "type": "array",
@@ -57,6 +76,8 @@ containerConfigProperties = {
         "type": "array",
         "items": {"type": "string"},
     },
+    "env": aliases,
+    "features": features,
     "aliases": {
         "oneOf": [
             aliases,
@@ -90,8 +111,12 @@ settingsProperties = {
     "singularity_module": {"type": ["string", "null"]},
     "bindpaths": {"type": ["string", "null"]},
     "updated_at": {"type": "string"},
+    "module_name": {"type": "string"},
+    "environment_file": {"type": "string"},
+    "container_tech": {"type": "string", "enum": ["singularity", "podman"]},
     "singularity_shell": {"type": "string", "enum": ["/bin/bash", "/bin/sh"]},
     "module_sys": {"type": "string", "enum": ["lmod", "tcl", None]},
+    "container_features": container_features,
 }
 
 
@@ -104,8 +129,11 @@ settings = {
         "registry",
         "module_base",
         "singularity_module",
+        "environment_file",
+        "container_tech",
         "bindpaths",
         "singularity_shell",
+        "container_features",
     ],
     "properties": settingsProperties,
 }
